Enum native_tls::HandshakeError [−][src]
pub enum HandshakeError<S> {
Failure(Error),
WouldBlock(MidHandshakeTlsStream<S>),
}Expand description
An error returned from ClientBuilder::handshake.
Variants
A fatal error.
Tuple Fields of Failure
0: ErrorA stream interrupted midway through the handshake process due to a
WouldBlock error.
Note that this is not a fatal error and it should be safe to call
handshake at a later time once the stream is ready to perform I/O
again.
Tuple Fields of WouldBlock
0: MidHandshakeTlsStream<S>